@@ -40,5 +40,9 @@ test_that("assess returns the correct classes", {
   expect_s3_class(
     assess_source_good$news_current,
     c("pkg_metric_news_current", "pkg_metric", "logical"))
+
+  expect_s3_class(
+    assess_source_good$has_examples,
+    c("pkg_metric_has_examples", "pkg_metric", "integer"))
 })
 
